@@ -1,6 +1,5 @@
 ## Export: inla.posterior.sample inla.posterior.sample.eval
 
-
 ##! \name{inla.sample}
 ##! \alias{inla.posterior.sample}
 ##! \alias{posterior.sample}
@@ -16,7 +15,7 @@
 ##!                           intern = FALSE,
 ##!                           use.improved.mean = TRUE, skew.corr = TRUE, 
 ##!                           add.names = TRUE, seed = 0L, num.threads = NULL, 
-##!                           verbose=FALSE)
+##!                           parallel.configs = TRUE,  verbose=FALSE)
 ##!     inla.posterior.sample.eval(fun, samples, return.matrix = TRUE, ...)
 ##! }
 ##! 
@@ -33,13 +32,6 @@
 ##!       are negative, they are interpreted as 'not', a zero is interpreted as 'all',  and
 ##!       positive indices are interpreted as 'only'. The names of elements of each samples 
 ##!       refer to the indices in the full sample. }
-##   \item{num.cores}{Number of cores to use in the \code{foreach} package.
-##        By default it only exploits one for a serial strategy of 
-##        the computations. For \code{num.cores} greater than 1 we are basically
-##        creating a single stream of tasks 
-##        that can all be executed in parallel. The number of threads employed
-##        by \code{inla.qsample},  the argument \code{num.threads},  are matched
-##        with the number of cores specified in the option \code{num.cores}.}
 ##!   \item{intern}{Logical. If \code{TRUE} then produce samples in the
 ##!        internal scale for the hyperparmater, if \code{FALSE} then produce
 ##!        samples in the user-scale. (For example log-precision (intern)
@@ -53,26 +45,35 @@
 ##!   \item{add.names}{Logical. If \code{TRUE} then add name for each elements of each
 ##!       sample. If \code{FALSE}, only add name for the first sample. 
 ##!       (This save space.)}
-##!   \item{seed}{Control the RNG of \code{inla.qsample},
-##!       see \code{?inla.qsample} for further information.
-##!       If \code{seed=0L} then GMRFLib will set the seed intelligently/at 'random'.
-##!       If \code{seed < 0L}  then the saved state of the RNG will be reused if possible, otherwise,
-##!       GMRFLib will set the seed intelligently/at 'random'.
-##!       If \code{seed > 0L} then this value is used as the seed for the RNG.
-##!       If you want reproducible results, you ALSO need to control the seed for the RNG in R by
-##!       controlling the variable \code{.Random.seed} or using the function \code{set.seed},
-##!       the example for how this can be done. }
-##!   \item{num.threads}{The number of threads that can be used. \code{num.threads>1L} requires
-##!       \code{seed = 0L}. Default value is controlled by \code{inla.getOption("num.threads")}}
+##!   \item{seed}{See the same argument in \code{?inla.qsample} for further
+##!               information. In order to produce reproducible results,  you
+##!               ALSO need to make sure the RNG in R is in the same state,
+##!               see example below.  When \code{seed} is non-zero,
+##!               \code{num.threads} is forced to "1:1" and parallel.configs is
+##!               set to \code{FALSE}, since parallel sampling would not produce
+##!               a reproducible sequence of pseudo-random numbers.}
+##!   \item{num.threads}{The number of threads to use in the format 'A:B' defining the number threads in the
+##!                      outer (A) and inner (B) layer for nested parallelism. A '0' will be replaced
+##!                      intelligently. 
+##!                      \code{seed!=0} requires serial comptuations.}
+##!   \item{parallel.configs}{Logical. If \code{TRUE} and not on Windows,
+##!                           then try to run each configuration in
+##!                           parallel (not Windows) using \code{A} threads (see \code{num.threads}), 
+##!                           where each of them is using \code{B:0} threads.}
 ##!   \item{verbose}{Logical. Run in verbose mode or not.}
 ##!   \item{fun}{The function to evaluate for each sample. Upon entry, the variable names
-##!               defined in the model are defined as the value of the sample.
-##!               The list of names are defined in \code{result$misc$configs$contents} where
-##!               \code{result} is an \code{inla}-object. This includes predefined names for
-##!               for the linear predictor (\code{Predictor} and \code{APredictor}),  and the
-##!               intercept (\code{(Intercept)} or \code{Intercept}).
-##!               The hyperparameters are defined as \code{theta},  no matter if they are in the
-##!               internal scale or not. The function \code{fun} can also return a vector.}
+##!              defined in the model are defined as the value of the sample.
+##!              The list of names are defined in \code{result$misc$configs$contents} where
+##!              \code{result} is an \code{inla}-object. This includes predefined names for
+##!              for the linear predictor (\code{Predictor} and \code{APredictor}),  and the
+##!              intercept (\code{(Intercept)} or \code{Intercept}).
+##!              The hyperparameters are defined as \code{theta},  no matter if they are in the
+##!              internal scale or not. The function \code{fun} can also return a vector.
+##!              To simplify usage, \code{fun} can also be a vector character's. In this case
+##!              \code{fun} it is interpreted as variable
+##!              names or subsets thereof, and a function is created that return these variables:
+##!              if argument \code{fun} equals \code{c("Intercept", "a[1:2]")},  then this is equivalent to
+##!              pass \code{function() return(c(Intercept, a[1:2]))}.}
 ##!   \item{samples}{\code{samples} is the output from \code{inla.posterior.sample()}}
 ##!   \item{return.matrix}{Logical. If \code{TRUE},  then return the samples of \code{fun}
 ##!                         as matrix,  otherwise,  as a list.}
@@ -109,9 +110,9 @@
 ##!  ## reproducible results:
 ##!  inla.seed = as.integer(runif(1)*.Machine$integer.max)
 ##!  set.seed(12345)
-##!  x = inla.posterior.sample(100, r, seed = inla.seed)
+##!  x = inla.posterior.sample(10, r, seed = inla.seed, num.threads="1:1")
 ##!  set.seed(12345)
-##!  xx = inla.posterior.sample(100, r, seed = inla.seed)
+##!  xx = inla.posterior.sample(10, r, seed = inla.seed, num.threads="1.1")
 ##!  all.equal(x, xx)
 ##!
 ##! set.seed(1234)
@@ -124,7 +125,7 @@
 ##!         data = data.frame(y, z, xx, yy), 
 ##!         control.compute = list(config=TRUE),
 ##!         family = "gaussian")
-##! r.samples = inla.posterior.sample(100, r)
+##! r.samples = inla.posterior.sample(10, r)
 ##! 
 ##! fun = function(...) {
 ##!     mean(xx) - mean(yy)
@@ -153,6 +154,10 @@
 ##!         control.compute = list(config=TRUE),
 ##!         family = "gaussian")
 ##! r.samples = inla.posterior.sample(10^3, r)
+##!  
+##! ## just return samples of the intercept
+##! intercepts = inla.posterior.sample.eval("Intercept", r.samples)
+##!
 ##! nz = 3
 ##! znew = rnorm(nz)
 ##! fun = function(zz = NA) {
@@ -217,7 +222,7 @@ inla.create.sn.cache <- function()
     } 
     
     ## This code section will run only once in order to create the local object 'sn.cache'
-    envir = INLA:::inla.get.inlaEnv()
+    envir = inla.get.inlaEnv()
     stopifnot(inla.require('sn'))
     
     ## The following quantities can be changed and affect the whole code
@@ -319,7 +324,7 @@ inla.posterior.sample = function(n = 1L, result, selection = list(),
                                  intern = FALSE,
                                  use.improved.mean = TRUE, skew.corr = TRUE, 
                                  add.names = TRUE, seed = 0L, num.threads = NULL, 
-                                 verbose = FALSE)
+                                 parallel.configs = TRUE, verbose = FALSE)
 {
     ## New inla.posterior.sample with skewness correction. contributed by CC.
     
@@ -329,20 +334,29 @@ inla.posterior.sample = function(n = 1L, result, selection = list(),
          'control.compute=list(config = TRUE)'.")
     }
     
-    if (seed != 0L && is.null(num.threads)) {
-        num.threads = 1L
-    }
     if (is.null(num.threads)) {
         num.threads = inla.getOption("num.threads")
     }
-    num.threads = max(num.threads, 1L)
-    if (num.threads > 1L && seed != 0L) {
-        stop("num.threads > 1L require seed = 0L")
+    if (seed != 0L) {
+        num.threads.user <- inla.parse.num.threads(num.threads)
+        num.threads <- inla.parse.num.threads("1:1")
+        if (num.threads != num.threads.user) {
+            warning("Since 'seed!=0', parallel model is disabled and serial model is selected, num.threads='1:1'")
+        }
+        ## Since parallel.configs aren't used on winows anyway, warning about
+        ## overriding it on other systems is overkill and doesn't really help.
+        #    if (!missing(parallel.configs) && !isFALSE(parallel.configs)) {
+        #        warning("Since 'seed!=0', parallel model is disabled and serial model is selected, parallel.configs=FALSE")
+        #    }
+        parallel.configs <- FALSE
+    } else {
+        num.threads <- inla.parse.num.threads(num.threads)
     }
+
     if (use.improved.mean == FALSE) {
         skew.corr <- FALSE
     }
-    if (skew.corr == TRUE && !exists("sn.cache", envir = INLA:::inla.get.inlaEnv())) {
+    if (skew.corr == TRUE && !exists("sn.cache", envir = inla.get.inlaEnv())) {
         ## function call for creating a local object in INLA environment
         inla.create.sn.cache()                          
     }
@@ -376,13 +390,60 @@ inla.posterior.sample = function(n = 1L, result, selection = list(),
     con = cs$contents
     all.samples = rep(list(c()), n)
     i.sample = 1L
+
+    ## it is easier to parallise here,  just doing the samples in parallel. then we process them
+    ## in serial afterwards, since that is much less of an job
+
+    if (!inla.os("windows") && parallel.configs) {
+        nt <- as.numeric(strsplit(num.threads, ":")[[1]])
+        ncores <- parallel::detectCores(all.tests = TRUE, logical = FALSE)
+        if (nt[1] == 0) {
+            nt[1] <- max(1, min(cs$nconfig, ncores))
+            nt[2] <- 1
+        } 
+        if (nt[2] == 0) {
+            nt[2] <- max(1, ncores %/% nt[1])
+        }
+        # In parallel mode, each thread needs it's own random sequence,
+        # so seed must be 0; seed != 0 is handled above to prevent parallel
+        # runs with nonzero seed.
+        xx.list <- parallel::mclapply(1:cs$nconfig,
+                             (function(k) {
+                                 if (n.idx[k] > 0) {
+                                     xx = inla.qsample(n = n.idx[k],
+                                                       Q = cs$config[[k]]$Q,
+                                                       mu = inla.ifelse(use.improved.mean,
+                                                                        cs$config[[k]]$improved.mean,
+                                                                        cs$config[[k]]$mean), 
+                                                       constr = cs$constr,
+                                                       logdens = TRUE,
+                                                       seed = 0L,
+                                                       num.threads = paste0(nt[2], ":1"), 
+                                                       selection = sel.map,
+                                                       verbose = verbose)
+                                     return (xx)
+                                 } else {
+                                     return (NA)
+                                 }
+                             }), 
+                             mc.cores = nt[1],
+                             mc.preschedule = TRUE)
+    } else {
+        xx.list <- NULL
+    }
+
     for(k in 1:cs$nconfig) {
         if (n.idx[k] > 0) {
             ## then the latent field
-            xx = inla.qsample(n = n.idx[k], Q = cs$config[[k]]$Q,
-                              mu = inla.ifelse(use.improved.mean, cs$config[[k]]$improved.mean, cs$config[[k]]$mean), 
-                              constr = cs$constr, logdens = TRUE, seed = seed, num.threads = num.threads,
-                              selection = sel.map, verbose = verbose)
+            if (is.null(xx.list)) {
+                xx = inla.qsample(n = n.idx[k], Q = cs$config[[k]]$Q,
+                                  mu = inla.ifelse(use.improved.mean, cs$config[[k]]$improved.mean, cs$config[[k]]$mean), 
+                                  constr = cs$constr, logdens = TRUE, seed = seed, num.threads = num.threads,
+                                  selection = sel.map, verbose = verbose)
+            }
+            else {
+                xx <- xx.list[[k]]
+            }
             ## if user set seed,  then just continue this rng-stream
             if (seed > 0L) seed = -1L
             
@@ -455,7 +516,7 @@ inla.posterior.sample = function(n = 1L, result, selection = list(),
                 C.th <- xx$logdens
             } else {
                 ## Skewness Correction applied on the samples
-                sh.cache = get("sn.cache", envir = INLA:::inla.get.inlaEnv())
+                sh.cache = get("sn.cache", envir = inla.get.inlaEnv())
                 dig = sh.cache$dig
                 s = sh.cache$s
                 skew.splines <- sh.cache$skew.splines
@@ -765,6 +826,16 @@ inla.posterior.sample = function(n = 1L, result, selection = list(),
         stop("Argument 'samples' must be the output from 'inla.posterior.sample()'.")
     }
 
+    ## special shorthand feature that is very useful. if this is vector of character's, then its
+    ## interpreted as a function returning these names, like ....eval(c("a", "b[1:2]"), ...)
+    ## will be converted into the function: function() return(c(a, b[1:2]))
+
+    if (is.character(fun)) {
+        fun <- inla.eval(paste("function() return(c(", paste(fun, sep = "", collapse = ", "), "))"))
+    } else {
+        fun <- match.fun(fun)
+    }
+
     my.fun = function(a.sample, .contents, .fun, ...) 
     {
         env = new.env()
