@@ -19,7 +19,7 @@
 ##!        seed = 0L,
 ##!        logdens = ifelse(missing(sample), FALSE, TRUE),
 ##!        compute.mean = ifelse(missing(sample), FALSE, TRUE),
-##!        num.threads = if (seed == 0L) 1L else NULL,
+##!        num.threads = if (seed == 0L) "0:0" else NULL,
 ##!        selection = NULL, verbose = FALSE)
 ##! }
 ##! 
@@ -34,14 +34,24 @@
 ##!        either one of the names listed in \code{inla.reorderings()} 
 ##!        or the output from \code{inla.qreordering(Q)}.
 ##!        The default is "auto" which try several reordering algorithm and use the best one for this particular matrix.}
-##!   \item{seed}{Control the RNG. If \code{seed=0L} then GMRFLib will set the seed intelligently/at 'random'.
+##!   \item{seed}{Control the RNG. If \code{seed=0L} then GMRFLib will set the seed
+##!               intelligently/at 'random',  and this is and should be the default behaviour.
 ##!               If \code{seed < 0L}  then the saved state of the RNG will be reused if possible, otherwise,
 ##!               GMRFLib will set the seed intelligently/at 'random'.
-##!               If \code{seed > 0L} then this value is used as the seed for the RNG.}
+##!               If \code{seed > 0L} then this value is used as the seed for the RNG.
+##!
+##!               PLEASE NOTE1: If \code{seed!=0} then the computations will run in serial mode,  over-riding
+##!               whatever is set in \code{num.threads} (a warning might be issued).
+##!
+##!               PLEASE NOTE2: If the PARDISO sparse matrix library is used, continuity of the samples
+##!               with respect to small changes in the precision matrix, can be expected but is
+##!               not guaranteed. If this feature is required, please use the TAUCS sparse matrix library.}
 ##!   \item{logdens}{If \code{TRUE}, compute also the log-density of each sample. Note that the output format then change.}
 ##!   \item{compute.mean}{If \code{TRUE}, compute also the (constrained) mean. Note that the output format then change.}
-##!   \item{num.threads}{The number of threads that can be used. \code{num.threads>1L} requires
-##!       \code{seed = 0L}.} 
+##!   \item{num.threads}{Maximum number of threads the
+##!                      \code{inla}-program will use, or as 'A:B' defining the number threads in the
+##!                      outer (A) and inner (B) layer for nested parallelism. 
+##!                      \code{seed!=0} requires serial comptuations.}
 ##!   \item{selection}{A vector of indices of each sample to
 ##!                    return. \code{NULL} means return the whole sample.
 ##!                    (Note that the log-density retured,  is for the whole sample.)
@@ -86,12 +96,12 @@
 ##! x = inla.qsample(n, Q=Q, constr=constr)
 ##! print(constr$A \%*\% x)
 ##! 
-##! ## control the RNG
-##! x = inla.qsample(n, Q=Q, seed = 123)
+##! ## control the RNG (require serial mode)
+##! x = inla.qsample(n, Q=Q, seed = 123, num.threads="1:1")
 ##! ## restart from same seed,  only sample 1
-##! xx = inla.qsample(n=1, Q=Q, seed = 123)
+##! xx = inla.qsample(n=1, Q=Q, seed = 123, num.threads="1:1")
 ##! ## continue from the save state, sample the remaining 2
-##! xxx = inla.qsample(n=n-1, Q=Q, seed = -1)
+##! xxx = inla.qsample(n=n-1, Q=Q, seed = -1, num.threads="1:1")
 ##! ## should be 0
 ##! print(x - cbind(xx, xxx))
 ##!}
@@ -107,7 +117,7 @@
         seed = 0L,
         logdens = ifelse(missing(sample), FALSE, TRUE), 
         compute.mean = ifelse(missing(sample), FALSE, TRUE),
-        num.threads = NULL, 
+        num.threads = if (seed == 0L) "0:0" else NULL,
         selection = NULL,
         verbose = FALSE)
 {
@@ -116,17 +126,17 @@
     stopifnot(!missing(Q))
     stopifnot(n >= 1L)
 
-    if (seed != 0L && is.null(num.threads)) {
-        num.threads = 1L
-    }
     if (is.null(num.threads)) {
         num.threads = inla.getOption("num.threads")
     }
-    num.threads = max(num.threads, 1L)
-    if (num.threads > 1L) {
-        if (seed != 0L) {
-            stop("num.threads > 1L require seed = 0L")
+    if (seed != 0L) {
+        num.threads.user <- inla.parse.num.threads(num.threads)
+        num.threads <- inla.parse.num.threads("1:1")
+        if (num.threads != num.threads.user) {
+            warning("Since 'seed!=0', parallel model is disabled and serial model is selected")
         }
+    } else {
+        num.threads <- inla.parse.num.threads(num.threads)
     }
 
     if (is.list(reordering)) {
@@ -210,13 +220,13 @@
     inla.set.sparselib.env(inla.dir = t.dir)
     if (inla.os("linux") || inla.os("mac")) {
         s = system(paste(shQuote(inla.call.no.remote()), "-s -m qsample",
-                         "-t", num.threads, "-r", reordering, "-z", seed, "-S", smtp,
+                         paste0("-t", num.threads), "-r", reordering, "-z", seed, "-S", smtp,
                          if (verbose) "-v" else "", 
                          Q.file, x.file, as.integer(n), rng.file,
-                         sample.file, b.file, mu.file, constr.file, cmean.file, selection.file), intern=FALSE)
+                         sample.file, b.file, mu.file, constr.file, cmean.file, selection.file), intern=TRUE)
     } else if(inla.os("windows")) {
         s = system(paste(shQuote(inla.call.no.remote()), "-s -m qsample",
-                         "-t", num.threads, "-r", reordering, "-z", seed, "-S", smtp,
+                         paste0("-t", num.threads), "-r", reordering, "-z", seed, "-S", smtp,
                          if (verbose) "-v" else "", 
                          Q.file, x.file, as.integer(n), rng.file,
                          sample.file, b.file, mu.file, constr.file, cmean.file, selection.file), intern=TRUE)
