@@ -140,7 +140,7 @@
         inla.ifelse(is.null(control$variant), 0L, as.integer(control$variant)),
         "\n", file = file,  append = TRUE)
 
-    if (inla.one.of(family, "cenpoisson")) {
+    if (inla.one.of(family, c("cenpoisson", "zeroinflatedcenpoisson0", "zeroinflatedcenpoisson1"))) {
         if (is.null(control$cenpoisson.I)) {
             interval = inla.set.control.family.default()$cenpoisson.I
         } else {
@@ -150,12 +150,19 @@
         if (length(interval) != 2L) {
             stop(paste("cenpoisson.I: Must be a vector of length 2.", length(interval)))
         }
-        if (interval[1] > interval[2]) {
-            stop(paste("cenpoisson.I = c(Low, High): Low > High!", interval[1],  interval[2]))
-        }
+        interval <- sort(pmax(0, interval))
+        stopifnot(all(is.infinite(interval) == FALSE))
         cat("cenpoisson.I = ", interval[1], " ",  interval[2], "\n", sep="", file=file, append=TRUE)
     }
     
+    if (inla.one.of(family, c("beta"))) {
+        c.val = control$beta.censor.value
+        if (c.val < 0 || c.val >= 0.5) {
+               stop(paste("beta.censor.value: Must be in the intervel 0 to 1/2", c.val))
+        }
+        cat("beta.censor.value = ", c.val, "\n", sep="", file=file, append=TRUE)
+    }
+
     if (TRUE) {
         if (!is.null(control$quantile))
             stop("control.family=list(quantile=...) is disabled. Use control.family=list(control.link=list(quantile=...)) instead")
@@ -170,11 +177,6 @@
         cat("quantile = ", quantile, "\n", sep="", file=file, append=TRUE)
     }
 
-    if (inla.one.of(family, c("sn", "skewnormal"))) {
-        cat("sn.shape.max = ", inla.ifelse(is.null(control$sn.shape.max), 5.0, control$sn.shape.max), "\n",
-            sep="", file=file, append=TRUE)
-    }
-
     if (inla.one.of(family, "gev")) {
         cat("gev.scale.xi = ", inla.ifelse(is.null(control$gev.scale.xi), 0.01, control$gev.scale.xi), "\n",
             sep="", file=file, append=TRUE)
@@ -786,7 +788,7 @@
     if (!(is.null(inla.spec$tolerance.step) || is.na(inla.spec$tolerance.step))) {
         cat("tolerance.step = ", inla.spec$tolerance.step,"\n", sep = " ", file = file, append = TRUE)
     }
-        
+    
     inla.write.boolean.field("hessian.force.diagonal", inla.spec$force.diagonal, file)
     inla.write.boolean.field("skip.configurations", inla.spec$skip.configurations, file)
     inla.write.boolean.field("mode.known", inla.spec$mode.known.conf, file)
@@ -794,6 +796,10 @@
     inla.write.boolean.field("lincomb.derived.only", inla.spec$lincomb.derived.only, file)
     inla.write.boolean.field("lincomb.derived.correlation.matrix", inla.spec$lincomb.derived.correlation.matrix, file)
 
+    if (inla.spec$lincomb.derived.only != TRUE) {
+        stop("Option 'control.inla$lincomb.derived.only' is disabled. Please remove.")
+    }
+
     if (!is.null(inla.spec$restart) && inla.spec$restart >= 0) {
         cat("restart = ", as.integer(inla.spec$restart), "\n", file = file, sep = " ", append = TRUE)
     }
@@ -921,6 +927,29 @@
         cat("control.correct.strategy = ", inla.spec$control.correct$strategy,"\n", sep = " ", file = file,  append = TRUE)
     }
 
+    num.gradient <- match.arg(tolower(inla.spec$num.gradient), c("central", "forward"))
+    num.hessian <- match.arg(tolower(inla.spec$num.hessian), c("central", "forward"))
+    optimise.strategy <- match.arg(tolower(inla.spec$optimise.strategy), c("plain", "smart"))
+    cat("num.gradient = ", num.gradient, "\n", sep = " ", file = file,  append = TRUE)
+    cat("num.hessian = ", num.hessian, "\n", sep = " ", file = file,  append = TRUE)
+    cat("optimise.strategy = ", optimise.strategy, "\n", sep = " ", file = file,  append = TRUE)
+
+    ud <- inla.spec$use.directions
+    if (is.null(ud)) ud <- FALSE
+    ud.val <- if (is.logical(ud) && (ud == FALSE)) FALSE else TRUE
+    inla.write.boolean.field("use.directions", ud.val, file)
+    if (ud.val && is.matrix(ud)) {
+        file.directions = inla.tempfile(tmpdir=data.dir)
+        inla.write.fmesher.file(as.matrix(ud), filename=file.directions)
+        fnm = gsub(data.dir, "$inladatadir", file.directions, fixed=TRUE)
+        cat("use.directions.matrix =", fnm, "\n", file=file, append = TRUE)
+    }
+
+    if (inla.spec$constr.marginal.diagonal > 0.0) {
+        cat("constr.marginal.diagonal = ", inla.spec$constr.marginal.diagonal, "\n", sep = " ", file = file,  append = TRUE)
+    }
+
+
     cat("\n", sep = " ", file = file,  append = TRUE)
 }
 
@@ -962,12 +991,7 @@
         cross = as.factor(predictor.spec$cross)
         cross = as.integer(cross)
         cross[is.na(cross)] = 0L ## means not in use
-        if (inla.getOption("internal.binary.mode")) {
-            inla.write.fmesher.file(as.matrix(cross, ncol=1L), filename=file.cross)
-        } else {
-            write(cross, ncolumns=1L, file=file.cross)
-        }
-
+        inla.write.fmesher.file(as.matrix(cross, ncol=1L), filename=file.cross)
         fnm = gsub(data.dir, "$inladatadir", file.cross, fixed=TRUE)
         cat("cross.constraint =", fnm, "\n", file=file, append = TRUE)
     }
@@ -1063,7 +1087,15 @@
         openmp.strategy = "default"
     }
     openmp.strategy = match.arg(tolower(openmp.strategy),
-                                c("default", "small", "medium", "large", "huge", "pardiso.serial", "pardiso.parallel"))
+                                c("default", "small", "medium", "large", "huge",
+                                  "pardiso.serial", "pardiso.parallel", "pardiso.nested", "pardiso"))
+    if (inla.one.of(openmp.strategy, c("pardiso.serial", "pardiso.parallel", "pardiso.nested"))) {
+        ## they are all the same now. this is for backward compatibility
+        warning(paste0("openmp.strategy='pardiso.serial', 'pardiso.parallel', or 'pardiso.nested', is the same as openmp.strategy='pardiso', ",
+                       "\nplease update your code. You define how the parallelisation is done using argument 'inla(...,  num.threads='A:B')'",
+                       "\nwhere A are the number of threads in the outer layer, and B in the inner layer."))
+        openmp.strategy <- "pardiso" 
+    }
     cat("openmp.strategy = ", openmp.strategy, "\n", sep = " ", file = file,  append = TRUE)
 
     if (!is.null(quantiles)) {
