@@ -215,7 +215,7 @@
     ##:EXTRA: 
     ##:NAME: control.compute
     list(
-        ##:ARGUMENT: openmp.strategy The computational strategy to use: 'small', 'medium', 'large', 'huge' and 'default'. There are also two options for the pardiso solver: 'pardiso.serial' and 'pardiso.parallel'. The difference is how the parallelisation is done, and is tuned for 'small'-sized models, 'medium'-sized models, etc. The default option tries to make an educated guess, but this allows to overide this selection. Default is 'default'
+        ##:ARGUMENT: openmp.strategy The computational strategy to use: 'small', 'medium', 'large', 'huge', 'default' and 'pardiso'.
         openmp.strategy = "default", 
 
         ##:ARGUMENT: hyperpar A boolean variable if the marginal for the hyperparameters should be computed. Default TRUE.
@@ -245,7 +245,7 @@
         ##:ARGUMENT: config A boolean variable if the internal GMRF approximations be stored. (Default FALSE. EXPERIMENTAL)
         config=FALSE,
 
-        ##:ARGUMENT: smtp The sparse-matrix solver, one of 'default', 'taucs', 'band' or 'pardiso' (default \code{inla.getoption("smtp")})
+        ##:ARGUMENT: smtp The sparse-matrix solver, one of 'default', 'taucs', 'band' or 'pardiso' (default \code{inla.getoption("smtp")}). \code{smtp='pardiso'} implies \code{openmp.strategy='pardiso'}.
         smtp = NULL,
 
         ##:ARGUMENT: graph A boolean variable if the graph itself should be returned. (Default FALSE.)
@@ -318,6 +318,9 @@
         ##:ARGUMENT: cenpoisson.I The censoring interval for the censored Poisson
         cenpoisson.I = c(-1L, -1L),
 
+        ##:ARGUMENT: beta.censor.value The censor value for the Beta-likelihood \code{(0 <= beta.censor.value < 1/2)}
+        beta.censor.value = 0.0, 
+
         ##:ARGUMENT: variant This variable is used to give options for various variants of the likelihood,  like chosing different parameterisations for example. See the relevant likelihood documentations for options (does only apply to some likelihoods).
         variant = 0L,
 
@@ -363,8 +366,11 @@
 
         ##:ARGUMENT: correlation.matrix Compute the posterior correlation matrix for all fixed effects? (default FALSE) OOPS: This option will set up appropriate linear combinations and the results are shown as the posterior correlation matrix of the linear combinations. This option will imply \code{control.inla=list(lincomb.derived.correlation.matrix=TRUE)}.
          
-        correlation.matrix = FALSE)
+        correlation.matrix = FALSE,
 
+        ##:ARGUMENT: remove.names A vector of names of expanded fixed effects to remove from the model-matrix. This is an expert option, and should only be used if you know what you are doing. 
+        remove.names = NULL
+    )
     ##:SEEALSO: inla
 }
 
@@ -398,8 +404,8 @@
         ##:ARGUMENT: linear.correction Logical Default TRUE for the 'strategy = laplace' option.
         linear.correction=NULL,
 
-        ##:ARGUMENT: h Numerical The step-length for the gradient calculations for the hyperparameters. Default 0.01.
-        h=0.01,
+        ##:ARGUMENT: h Numerical The step-length for the gradient calculations for the hyperparameters. Default 0.005.
+        h = 0.005,
 
         ##:ARGUMENT: dz Numerical The step-length in the standarised scale for the integration of the hyperparameters. Default 0.75.
         dz=0.75,
@@ -479,7 +485,7 @@
         ##:ARGUMENT: stencil Numerical Number of points in the stencil used to compute the numerical derivaties of the log-likelihood (3, 5, 7 or 9). (default 5)
         stencil = 5L, 
 
-        ##:ARGUMENT: lincomb.derived.only Logical If TRUE the only compute the marginals for the derived linear combinations and if FALSE, the and also the linear combinations to the graph (Default TRUE)
+        ##:ARGUMENT: lincomb.derived.only Logical THIS OPTION IS NOW DISABLED (July 2021) AND WILL BE REMOVED IN A FUTURE VERSION. (If TRUE the only compute the marginals for the derived linear combinations and if FALSE, the and also the linear combinations to the graph (Default TRUE))
         lincomb.derived.only = TRUE,
 
         ##:ARGUMENT: lincomb.derived.correlation.matrix Logical If TRUE compute also the correlations for the derived linear combinations, if FALSE do not (Default FALSE)
@@ -527,7 +533,22 @@
         control.vb = list(enable = FALSE, strategy = "mean", verbose = TRUE, refinement = 0, max.correct = 1.0, hyperpar.correct = FALSE),
 
         ##:ARGUMENT: control.correct List of control arguments for correction for the Laplace approximation: \code{enable} Logical Use this feature? \code{factor} Numerical Factor used in adjusting the correction factor (default=10) if \code{correct=TRUE}. \code{strategy}  Character The strategy used to compute the correction; one of 'simplified.laplace' (default) or 'laplace'. \code{verbose}  Logical Be verbose when computing the correction? (default \code{FALSE})
-        control.correct = list(enable = FALSE, factor = 10.0, strategy = "simplified.laplace", verbose = FALSE)
+        control.correct = list(enable = FALSE, factor = 10.0, strategy = "simplified.laplace", verbose = FALSE), 
+
+        ##:ARGUMENT: num.gradient Character Set the numerical scheme to compute the gradient,  one of \code{"forward"} or \code{"central"} (default).
+        num.gradient = "central",
+        
+        ##:ARGUMENT: num.hessian Character Set the numerical scheme to compute the Hessian,  one of \code{"forward"} or \code{"central"} (default).
+        num.hessian = "central",
+        
+        ##:ARGUMENT: optimise.strategy Character THIS OPTION IS EXPERIMENTAL. Chose the optimiser strategy,  one of \code{"plain"} or \code{"smart"} (default)
+        optimise.strategy = "smart", 
+
+        ##:ARGUMENT: use.directions THIS OPTION IS EXPERIMENTAL. Unless \code{FALSE} or \code{NULL},  use directions for computing gradient and Hessian, initialised with \code{use.directions} if a matrix.
+        use.directions = TRUE, 
+
+        ##:ARGUMENT: constr.marginal.diagonal Add stability to \code{AQ^-1A^T} by adding a small diagonal term. (default \code{epsilon^0.5})
+        constr.marginal.diagonal = sqrt(.Machine$double.eps)
 
         )
         
@@ -630,7 +651,7 @@
     ##:EXTRA:
     ##:NAME: control.hazard
     list(
-        ##:ARGUMENT: model The model for the baseline hazard model. One of 'rw1' or 'rw2'. (Default 'rw1'.)
+        ##:ARGUMENT: model The model for the baseline hazard model. One of 'rw1', 'rw2' or 'iid'. (Default 'rw1'.)
         model = "rw1",
 
         ##:ARGUMENT: hyper The definition of the hyperparameters.
