@@ -41,8 +41,8 @@
         return (string)
     }
 
-    date       =  inla.trim("Sun 12 Jul 2020 03:41:33 PM +03")
-    version      =  inla.trim("20.07.12")
+    date       =  inla.trim("Sun Nov 29 02:12:08 PM +03 2020")
+    version      =  inla.trim("20.11.29")
     what = match.arg(what)
 
     if (what %in% "default") {
